==> huaweicloudsdkgaussdbfornosql-3.1.137-py2.py3-none-any.whl: huaweicloudsdkgaussdbfornosql/v3/model/batch_upgrade_database_version_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchUpgradeDatabaseVersionResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'upgrade_results': 'list[UpgradeResult]'
    }

    attribute_map = {
        'upgrade_results': 'upgrade_results'
    }

    def __init__(self, upgrade_results=None):
        """BatchUpgradeDatabaseVersionResponse

        The model defined in huaweicloud sdk

        :param upgrade_results: 批量升级结果。
        :type upgrade_results: list[:class:`huaweicloudsdkgaussdbfornosql.v3.UpgradeResult`]
        """
        
        super(BatchUpgradeDatabaseVersionResponse, self).__init__()

        self._upgrade_results = None
        self.discriminator = None

        if upgrade_results is not None:
            self.upgrade_results = upgrade_results

    @property
    def upgrade_results(self):
        """Gets the upgrade_results of this BatchUpgradeDatabaseVersionResponse.

        批量升级结果。

        :return: The upgrade_results of this BatchUpgradeDatabaseVersionResponse.
        :rtype: list[:class:`huaweicloudsdkgaussdbfornosql.v3.UpgradeResult`]
        """
        return self._upgrade_results

    @upgrade_results.setter
    def upgrade_results(self, upgrade_results):
        """Sets the upgrade_results of this BatchUpgradeDatabaseVersionResponse.

        批量升级结果。

        :param upgrade_results: The upgrade_results of this BatchUpgradeDatabaseVersionResponse.
        :type upgrade_results: list[:class:`huaweicloudsdkgaussdbfornosql.v3.UpgradeResult`]
        """
        self._upgrade_results = upgrade_results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchUpgradeDatabaseVersionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdbfornosql-3.1.153-py2.py3-none-any.whl: huaweicloudsdkgaussdbfornosql/v3/model/batch_upgrade_database_version_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchUpgradeDatabaseVersionResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'upgrade_results': 'list[UpgradeResult]'
    }

    attribute_map = {
        'upgrade_results': 'upgrade_results'
    }

    def __init__(self, upgrade_results=None):
        r"""BatchUpgradeDatabaseVersionResponse

        The model defined in huaweicloud sdk

        :param upgrade_results: 批量升级结果。
        :type upgrade_results: list[:class:`huaweicloudsdkgaussdbfornosql.v3.UpgradeResult`]
        """
        
        super(BatchUpgradeDatabaseVersionResponse, self).__init__()

        self._upgrade_results = None
        self.discriminator = None

        if upgrade_results is not None:
            self.upgrade_results = upgrade_results

    @property
    def upgrade_results(self):
        r"""Gets the upgrade_results of this BatchUpgradeDatabaseVersionResponse.

        批量升级结果。

        :return: The upgrade_results of this BatchUpgradeDatabaseVersionResponse.
        :rtype: list[:class:`huaweicloudsdkgaussdbfornosql.v3.UpgradeResult`]
        """
        return self._upgrade_results

    @upgrade_results.setter
    def upgrade_results(self, upgrade_results):
        r"""Sets the upgrade_results of this BatchUpgradeDatabaseVersionResponse.

        批量升级结果。

        :param upgrade_results: The upgrade_results of this BatchUpgradeDatabaseVersionResponse.
        :type upgrade_results: list[:class:`huaweicloudsdkgaussdbfornosql.v3.UpgradeResult`]
        """
        self._upgrade_results = upgrade_results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchUpgradeDatabaseVersionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
